AccessDescription class

Constructors

AccessDescription({String? accessLocation, ObjectIdentifier? accessMethod})
AccessDescription.fromAsn1(ASN1Sequence sequence)
The ASN.1 definition is: AccessDescription ::= SEQUENCE { accessMethod OBJECT IDENTIFIER, accessLocation GeneralName }
factory

Properties

accessLocation → String?
final
accessMethod → ObjectIdentifier?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited