AlgorithmIdentifier class

Constructors

AlgorithmIdentifier(ObjectIdentifier algorithm, dynamic parameters)
AlgorithmIdentifier.fromAsn1(ASN1Sequence sequence)
AlgorithmIdentifier ::= SEQUENCE { algorithm OBJECT IDENTIFIER, parameters ANY DEFINED BY algorithm OPTIONAL } -- contains a value of the type -- registered for use with the -- algorithm object identifier value
factory

Properties

algorithm → ObjectIdentifier
final
hashCode → int
The hash code for this object.
no setterinherited
parameters → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAsn1() → ASN1Sequence
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited