EncryptedPrivateKeyInfo class

Constructors

EncryptedPrivateKeyInfo(AlgorithmIdentifier encryptionAlgorithm, Uint8List encryptedData)
EncryptedPrivateKeyInfo.fromAsn1(ASN1Sequence sequence)
EncryptedPrivateKeyInfo ::= SEQUENCE { encryptionAlgorithm AlgorithmIdentifier, encryptedData OCTET STRING }
factory

Properties

encryptedData → Uint8List
final
encryptionAlgorithm → AlgorithmIdentifier
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited