Extension class

An X.509 extension

Constructors

Extension({required ObjectIdentifier extnId, bool isCritical = false, required ExtensionValue extnValue})
const
Extension.fromAsn1(ASN1Sequence sequence)
Creates a Extension from an ASN1Sequence.
factory

Properties

extnId → ObjectIdentifier
The extension's object identifier.
final
extnValue → ExtensionValue
The extension's value.
final
hashCode → int
The hash code for this object.
no setterinherited
isCritical → bool
Returns true if this extension is critical.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString([String prefix = '']) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited