KeyUsage class

The key usage extension defines the purpose (e.g., encipherment, signature, certificate signing) of the key contained in the certificate.

Inheritance

Constructors

KeyUsage({required bool digitalSignature, required bool nonRepudiation, required bool keyEncipherment, required bool dataEncipherment, required bool keyAgreement, required bool keyCertSign, required bool cRLSign, required bool encipherOnly, required bool decipherOnly})
const
KeyUsage.fromAsn1(ASN1BitString bitString)
Creates a key usage extension from an ASN1BitString.
factory

Properties

cRLSign → bool
True when the subject public key is used for verifying signatures on certificate revocation lists (e.g., CRLs, delta CRLs, or ARLs).
final
dataEncipherment → bool
True when the subject public key is used for directly enciphering raw user data without the use of an intermediate symmetric cipher.
final
decipherOnly → bool
When true (and the keyAgreement bit is also set), the subject public key may be used only for deciphering data while performing key agreement.
final
digitalSignature → bool
True when the subject public key is used for verifying digital signatures, other than signatures on certificates and CRLs, such as those used in an entity authentication service, a data origin authentication service, and/or an integrity service.
final
encipherOnly → bool
When true (and the keyAgreement bit is also set), the subject public key may be used only for enciphering data while performing key agreement.
final
hashCode → int
The hash code for this object.
no setterinherited
keyAgreement → bool
True when the subject public key is used for key agreement.
final
keyCertSign → bool
True when the subject public key is used for verifying signatures on public key certificates.
final
keyEncipherment → bool
True when the subject public key is used for enciphering private or secret keys, i.e., for key transport.
final
nonRepudiation → bool
True when the subject public key is used to verify digital signatures, other than signatures on certificates and CRLs, used to provide a non-repudiation service that protects against the signing entity falsely denying some action. In the case of later conflict, a reliable third party may determine the authenticity of the signed data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited