ObjectIdentifier class

Constructors

ObjectIdentifier(List<int> nodes)
const
ObjectIdentifier.fromAsn1(ASN1ObjectIdentifier id)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
no setter
nodes → List<int>
final
parent → ObjectIdentifier?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAsn1() → ASN1ObjectIdentifier
toString() → String
A string representation of this object.
override

Operators

operator ==(dynamic other) → bool
The equality operator.
override