SubjectKeyIdentifier class

The subject key identifier extension provides a means of identifying certificates that contain a particular public key.

Inheritance

Constructors

SubjectKeyIdentifier(List<int>? keyIdentifier)
SubjectKeyIdentifier.fromAsn1(ASN1Object obj)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyIdentifier → List<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited