Validity class

Constructors

Validity({required DateTime notBefore, required DateTime notAfter})
Validity.fromAsn1(ASN1Sequence sequence)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
notAfter → DateTime
final
notBefore → DateTime
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAsn1() → ASN1Sequence
toString([String prefix = '']) → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited